@@ -4,6 +4,19 @@ from enum import Enum, IntEnum
 
 LOGGER = logging.getLogger("openzwavemqtt")
 
+# Attribute names for utility functions
+ATTR_CODE_SLOT = "code_slot"
+ATTR_IN_USE = "in_use"
+ATTR_LABEL = "label"
+ATTR_MAX = "max"
+ATTR_MIN = "min"
+ATTR_NAME = "name"
+ATTR_OPTIONS = "options"
+ATTR_PARAMETER = "parameter"
+ATTR_POSITION = "position"
+ATTR_TYPE = "type"
+ATTR_VALUE = "value"
+
 # OZW Events
 EVENT_PLACEHOLDER = "missing"
 EVENT_COMMAND_CLASS_ADDED = "command_class_added"
@@ -67,6 +80,7 @@ class ValueGenre(Enum):
     USER = "User"
     SYSTEM = "System"
     BASIC = "Basic"
+    CONFIG = "Config"
     UNKNOWN = None
 
 
@@ -80,7 +94,10 @@ class ValueType(Enum):
     BYTE = "Byte"
     SHORT = "Short"
     INT = "Int"
+    BITSET = "BitSet"
+    RAW = "Raw"
     BUTTON = "Button"
+    SCHEDULE = "Schedule"
     UNKNOWN = None
 
 
@@ -95,6 +112,8 @@ class ValueIndex(IntEnum):
     BARRIER_OPERATOR_LABEL = 1
     # DoorLock
     DOOR_LOCK_LOCK = 0
+    CLEAR_USER_CODE = 256
+    NUM_USER_CODES = 257
     # Meter
     METER_POWER = 2
     METER_RESET = 257
@@ -214,6 +233,9 @@ class ValueIndex(IntEnum):
     NOTIFICATION_WEATHER = 16
     NOTIFICATION_IRRIGATION = 17
     NOTIFICATION_GAS = 18
+    # Notification Event Parameter
+    NOTIFICATION_EVENT_PARAMETER_PREVIOUS_EVENT_CLEARED = 256
+    NOTIFICATION_EVENT_PARAMETER_USER_CODE = 260
     UNKNOWN = 999
     # Version
     VERSION_LIBRARY = 0
